@@ -1,6 +1,6 @@
  
    create function plruby_call_handler() returns language_handler
-    as '/home/ts/ruby/perso/plruby-0.4.2/src/plruby.so'
+    as '/opt/ts/ruby/perso/plruby-0.4.3/src/plruby.so'
    language 'C';
  
 create trusted procedural language 'plruby'
